@@ -1,5 +1,6 @@
 package Module::Build::Convert;
 
+use 5.005;
 use strict;
 use warnings; 
 
@@ -13,7 +14,7 @@ use File::Slurp ();
 use File::Spec ();
 use IO::File ();
 
-our $VERSION = '0.21_02';
+our $VERSION = '0.25_01';
 
 sub new {
     my ($self, %params) = (shift, @_);
@@ -44,16 +45,12 @@ sub new {
 
 sub convert {
     my $self = shift;
-    $self->_create_rcfile if $self->{Config}{Create_RC};
-    $self->_makefile_ok;
-    print "Converting $self->{Config}{Makefile_PL} -> $self->{Config}{Build_PL}\n";
-    $self->_get_data;
-    if ($self->{Config}{Exec_Makefile}) {
-        print "Executing $self->{Config}{Makefile_PL}\n";
-        $self->_run_makefile;
-    } else {
-        $self->_parse_makefile;
+    if (!$self->{Config}{reinit}) {
+        $self->_create_rcfile if $self->{Config}{Create_RC};
+        $self->_makefile_ok;
+        $self->_get_data;
     }
+    $self->_extract_args;
     $self->_convert;
     $self->_dump;
     $self->_write;
@@ -88,44 +85,12 @@ sub _makefile_ok {
     }
     die "$self->{Config}{Makefile_PL} does not consist of WriteMakefile()\n"
       unless $makefile =~ /WriteMakefile\s*\(/s;
-    die "Indirect arguments to WriteMakefile() via hash are not supported\n" 
-      if $makefile =~ /WriteMakefile\(\s*%\w+.*\s*\)/s && !$self->{Config}{Exec_Makefile};
+    $self->_do_verbose("Converting $self->{Config}{Makefile_PL} -> $self->{Config}{Build_PL}\n");
+    warn "Indirect arguments to WriteMakefile() via hash detected, setting executing mode\n" 
+      and $self->{Config}{Exec_Makefile} = 1
+          if $makefile =~ /WriteMakefile\(\s*%\w+.*\s*\)/s && !$self->{Config}{Exec_Makefile};
 }
 
-sub _run_makefile {
-    my $self = shift;
-    no warnings 'redefine';
-    *ExtUtils::MakeMaker::WriteMakefile = sub {
-      %{$self->{make_args}} = @{$self->{make_args_arr}} = @_;
-    };
-    # beware, do '' overwrites existing globals
-    $self->_save_globals;
-    do $self->{Config}{Makefile_PL};
-    $self->_restore_globals;
-}
-
-sub _save_globals {
-    my $self = shift;
-    my @vars;
-    my $makefile = File::Slurp::read_file($self->{Config}{Makefile_PL});
-    $makefile =~ s/.*WriteMakefile\(\s*?(.*?)\);.*/$1/s;
-    while ($makefile =~ s/\$(\w+)//) {
-        push @vars, $1 if defined(${$1});
-    }
-    no strict 'refs';
-    for my $var (@vars) {
-        ${__PACKAGE__.'::globals'}{$var} = ${$var};
-    }
-}
-
-sub _restore_globals {
-    my $self = shift;
-    no strict 'refs';
-    while (my ($var, $value) = each %{__PACKAGE__.'::globals'}) {
-        ${__PACKAGE__.'::'.$var} = $value;
-    }
-}    
-
 sub _get_data {
     my $self = shift;
     my @data = $self->_parse_data;
@@ -171,8 +136,8 @@ sub _parse_data {
     unless ($create_rc) {
         # superfluosity
         shift @data_parsed;
-        chomp($data_parsed[-1]);
-	for my $line (split /\n/, $data_parsed[0]) {
+	chomp($data_parsed[-1]);
+	foreach my $line (split /\n/, $data_parsed[0]) {
 	    next unless $line;
 	    if ($line =~ /^#/) {
 	        my ($arg) = split /\s+/, $line;
@@ -184,69 +149,140 @@ sub _parse_data {
     return $create_rc ? $data : @data_parsed;
 }
 
+sub _extract_args {
+    my $self = shift;
+    if ($self->{Config}{Exec_Makefile}) {
+        $self->_do_verbose("Executing $self->{Config}{Makefile_PL}\n");
+        $self->_run_makefile;
+    } else {
+        $self->_parse_makefile;
+    }
+}
+
+sub _run_makefile {
+    my $self = shift;
+    no warnings 'redefine';
+    *ExtUtils::MakeMaker::WriteMakefile = sub {
+      %{$self->{make_args}} = @{$self->{make_args_arr}} = @_;
+    };
+    # beware, do '' overwrites existing globals
+    $self->_save_globals;
+    do $self->{Config}{Makefile_PL};
+    $self->_restore_globals;
+}
+
+sub _save_globals {
+    my $self = shift;
+    my @vars;
+    my $makefile = File::Slurp::read_file($self->{Config}{Makefile_PL});
+    $makefile =~ s/.*WriteMakefile\(\s*?(.*?)\);.*/$1/s;
+    while ($makefile =~ s/\$(\w+)//) {
+        push @vars, $1 if defined(${$1});
+    }
+    no strict 'refs';
+    foreach my $var (@vars) {
+        ${__PACKAGE__.'::globals'}{$var} = ${$var};
+    }
+}
+
+sub _restore_globals {
+    my $self = shift;
+    no strict 'refs';
+    while (my ($var, $value) = each %{__PACKAGE__.'::globals'}) {
+        ${__PACKAGE__.'::'.$var} = $value;
+    }
+    undef %{__PACKAGE__.'::globals'};
+}
+
 sub _parse_makefile {
     my $self = shift;
-    my (@histargs, %makeargs);
-    my $makefile = File::Slurp::read_file($self->{Config}{Makefile_PL});
-    $makefile =~ s/(.*)WriteMakefile\(\s*?(.*?)\);(.*)/$2/s;
-    my $makecode_begin = $1;
-    my $makecode_end   = $3;
-    $makecode_begin =~ s/\s*([#\w]+.*;)\s*/$1/s;
-    $makecode_end   =~ s/\s*([#\w]+.*;)\s*/$1/s;
-    $self->{make_code}{begin} = $makecode_begin;
-    $self->{make_code}{end}   = $makecode_end;
+    my (@histargs, %makeargs, $makefile, %trapped_loop);
+    my $found_string = qr/^ 
+                            \s* 
+                            ['"]? (\w+) ['"]? 
+			    \s* => \s* 
+			    ['"]? ([\$ \@ \% \\ \/ \- \: \. \w]+ .*?) ['"]?
+			    (?: ,? \n? | ,? (\s+ \# \s+ \w+ .*?) \n)
+                       /x;
+    my $found_array  = qr/^ 
+                            \s*
+                            ['"]? (\w+) ['"]?
+			    \s* => \s*
+			    \[ \s* (.*?) \s* \]
+			    (?: ,? \n | ,? (\s+ \# \s+ \w+ .*?) \n)
+                       /sx;
+    my $found_hash   = qr/^ 
+                            \s* 
+                            ['"]? (\w+) ['"]?
+			    \s* => \s*
+			    \{ \s* (.*?) \s*? \}
+			    (?: ,? \n? | ,? (\s+ \# \s+ \w+ .*?) \n)
+	               /sx;
+    ($makefile, $self->{make_code}{begin}, $self->{make_code}{end}) = $self->_read_makefile;
     $self->_debug("Entering parse\n");
     while ($makefile) {
-        if ($makefile =~ s/^\s*['"]?(\w+)['"]?\s+=>\s+(?![\[\{])['"]?([-\$\w]?.*?)['"]?(?:,\n|,(\s+#\s+\w+.*?)\n)//) {
+        if ($makefile =~ s/$found_string//) {
 	    my ($arg, $value, $comment) = ($1,$2,$3);
 	    $comment ||= '';
+	    $value =~ tr/['"]//d;
             $makeargs{$arg} = $value;
 	    push @histargs, $arg;
             if (defined($comment) && defined($self->{Data}{table}{$arg})) {
                 $self->{make_comments}{$self->{Data}{table}{$arg}} = $comment;
 	    }
-	    $self->_debug("Found scalar:\narg: $arg\nvalue: $value\ncomment: $comment\nmake args:\n$makefile\n\n");
-	} elsif ($makefile =~ s/^\s*['"]?(\w+)['"]?\s+=>\s+\[\s*(.*?)\s*\](?:,\n|,(\s+#\s+\w+.*?)\n)//s) {
+	    $self->_debug("Found string\narg: $arg\nvalue: $value\ncomment: $comment\nremaining args:\n$makefile\n\n");
+	} elsif ($makefile =~ s/$found_array//s) {
 	    my ($arg, $values, $comment) = ($1,$2,$3);
 	    $comment ||= '';
-	    $values =~ tr/[',]//d;
-	    $makeargs{$arg} = [ split /\s+/, $values ];
+	    $makeargs{$arg} = [ map { tr/['",]//d; $_ } split /,\s*/, $values ];
 	    push @histargs, $arg;
 	    if (defined($comment) && defined($self->{Data}{table}{$arg})) {
                 $self->{make_comments}{$self->{Data}{table}{$arg}} = $comment;
 	    }
-	    $self->_debug("Found array:\narg: $arg\nvalues: $values\ncomment: $comment\nmake args:\n$makefile\n\n");
-	} elsif ($makefile =~ s/^\s*['"]?(\w+)['"]?\s+=>\s+\{\s*(.*?)\s*\}(?:,\n|,(\s+#\s+\w+.*?)\n)//s) {
+	    $self->_debug("Found array\narg: $arg\nvalues: $values\ncomment: $comment\nremaining args:\n$makefile\n\n");
+	} elsif ($makefile =~ s/$found_hash//s) {
 	    my ($arg, $values, $comment) = ($1,$2,$3);
 	    $comment ||= '';
-	    my @values = split /,\ /, $values;
-	    local $/ = ','; 
-	    chomp(@values);
-	    my @values_new;
-	    for my $value (@values) {
-	        my @values = split /\s+=>\s+/, $value;
-		push @values_new, @values;
+	    my @values = split /,\s*/, $values;
+	    my @values_clean;
+	    foreach my $value (@values) {
+		push @values_clean, map { tr/['",]//d; $_ } split /\s*=>\s*/, $value;
 	    }
-	    @values = map { tr/'//d; $_ } @values_new;
+	    @values = @values_clean;
 	    $makeargs{$arg} = { @values };
 	    push @histargs, $arg;
             if (defined($comment) && defined($self->{Data}{table}{$arg})) {
                 $self->{make_comments}{$self->{Data}{table}{$arg}} = $comment;
 	    }
-	    $self->_debug("Found hash:\narg: $arg\nvalues: $values\ncomment: $comment\nmake args:\n$makefile\n\n");
+	    $self->_debug("Found hash\nkey: $arg\nvalues: $values\ncomment: $comment\nremaining args:\n$makefile\n\n");
 	} else {
-	    my $makecode;
-	    if ($makefile =~ s/^\s+(.*?\:\s+\(.*\)\s*),\n//s) {
-		$makecode = $1;
-	    } elsif ($makefile =~ s/^\s*([$@%]\w+)\s*//) {
-                $makecode = $1;
-            } elsif ($makefile =~ s/^\s*(#.*?)\n//) {
+	    my ($debug_desc, $makecode);
+	    if ($makefile =~ s/^\s*(\#.*)\n//s) {
+	        $debug_desc = 'comment';
 	        $makecode = $1;
-	    } else {
-                $makefile =~ s/^\s+(.*?)[,]\s*//;
+	    } elsif ($makefile =~ s/^\s*(['"]?\w+['"]?\s*=>\s*<<['"]?(.*?)['"]?,.*\2)//s) {
+	        $debug_desc = 'here-doc';
+                $makecode = $1;
+	    } elsif ($makefile =~ s/^\s*(\(?.*\?.*\:(.*?\),|.*['"],))\s*//s) {
+	        $debug_desc = 'ternary operator';
+		$makecode = $1;
+            } elsif ($makefile =~ s/^\s*([\Q$@%\E]\w+)\s*//) {
+	        $debug_desc = 'variable';
+                $makecode = $1;
+            } else {
+                $makefile =~ s/^\s*(.*?)\s*//;
+		$debug_desc = 'unknown';
                 $makecode = $1;
             }
-	    SUBST: for my $make (keys %{$self->{Data}{table}}) {
+	    $trapped_loop{$makecode}++;
+	    if ($trapped_loop{$makecode} >= 2) {
+	        $self->{Config}{Exec_Makefile} = 1;
+	        $self->{Config}{reinit} = 1;
+	    	$self->convert;
+	    	exit;
+	    }
+	    $self->_debug("Found code\n$debug_desc: $makecode\nremaining args:\n$makefile\n\n");
+	    SUBST: foreach my $make (keys %{$self->{Data}{table}}) {
 		if ($makecode =~ /\b$make\b/s) {
 		    $makecode =~ s/$make/$self->{Data}{table}{$make}/;
 		    last SUBST;
@@ -254,17 +290,29 @@ sub _parse_makefile {
             }
 	    pop @histargs until $self->{Data}{table}{$histargs[-1]};
 	    push @{$self->{make_code}{$self->{Data}{table}{$histargs[-1]}}}, $makecode;
-	    $self->_debug("Found code:\ncode: $makecode\nmake args:\n$makefile\n\n");
 	}
     }
     $self->_debug("Leaving parse\n");
     %{$self->{make_args}} = %makeargs;
 }
 
+sub _die { die }
+
+sub _read_makefile {
+    my $self = shift;
+    my $makefile = File::Slurp::read_file($self->{Config}{Makefile_PL});
+    $makefile =~ s/^(.*)\&?WriteMakefile\s*?\(\s*(.*?)\s*\)\s*?;(.*)$/$2/s;
+    my $makecode_begin = $1;
+    my $makecode_end   = $3;
+    $makecode_begin =~ s/\s*([\#\w]+.*)\s*/$1/s;
+    $makecode_end   =~ s/\s*([\#\w]+.*)\s*/$1/s;
+    return ($makefile, $makecode_begin, $makecode_end);
+}
+
 sub _convert {
     my $self = shift;                        
     $self->_insert_args; 
-    for my $arg (keys %{$self->{make_args}}) {
+    foreach my $arg (keys %{$self->{make_args}}) {
         if ($self->{disabled}{$arg}) {
 	    $self->_do_verbose("*** $arg disabled, skipping\n");
 	    next;
@@ -364,7 +412,7 @@ sub _sort_args {
 	my $i = 0;
 	if ($self->{Config}{Use_Native_Order}) {
 	    my %slot;
-	    for my $arg (grep $have_args{$_}, @{$self->{Data}{sort_order}}) {
+	    foreach my $arg (grep $have_args{$_}, @{$self->{Data}{sort_order}}) {
 	        if ($native_sortorder{$arg}) {
 	            $sortorder{$arg} = $native_sortorder{$arg};
 		    $slot{$native_sortorder{$arg}} = 1;
@@ -428,40 +476,48 @@ sub _write {
     $self->_write_end;
     $fh->close;
     select($selold);
-    print "Conversion done\n";
+    $self->_do_verbose("Conversion done\n");
 }
 
 sub _compose_header {
     my $self = shift;
-    my ($insert_comments, $insert_statements);
+    my ($comments_header, $code_header) = ('','');
     my $note = '# Note: this file has been initially generated by '.__PACKAGE__." $VERSION";
+    my $pragmas = "use strict;\nuse warnings;\n";
     if (defined($self->{make_code}{begin})) {
         $self->_do_verbose("Removing ExtUtils::MakeMaker as dependency\n");
-        $self->{make_code}{begin} =~ s/[ ]*(?:require|use)\s+ExtUtils::MakeMaker\s*;//;
-        $insert_comments ||= '';
-        while ($self->{make_code}{begin} =~ s/^(#[!]?.*?\n)//) {
-            $insert_comments .= $1;
+        $self->{make_code}{begin} =~ s/[ \t]*(?:use|require)\s+ExtUtils::MakeMaker\s*;//;
+	# Removing pragmas quietly here to ensure that they'll be inserted after
+	# an eventually appearing version requirement.
+	$self->{make_code}{begin} =~ s/[ \t]*use\s+(?:strict|warnings)\s*;//g;
+        while ($self->{make_code}{begin} =~ s/^(\#\!?.*?\n)//) {
+            $comments_header .= $1;
         }
-	chomp($insert_comments);
-        $insert_statements ||= '';
-        while ($self->{make_code}{begin} =~ /(?:require|use)\s+.*?;/) {
+	chomp($comments_header);
+        while ($self->{make_code}{begin} =~ /(?:use|require)\s+.*?;/) {
             $self->{make_code}{begin} =~ s/^\n?(.*?;)//s;
-	    $insert_statements .= "$1\n";
+	    $code_header .= "$1\n";
         }
-	chomp($insert_statements);
+	$self->_do_verbose("Adding use strict & use warnings pragmas\n");
+	if ($code_header =~ /(?:use|require)\s+\d\.[\d_]*\s*;/) { 
+            $code_header =~ s/([ \t]*(?:use|require)\s+\d\.[\d_]*\s*;\n)(.*)/$1$pragmas$2/;
+	} else {
+	    $code_header = $pragmas . $code_header;
+	}
+	chomp($code_header);
 	1 while $self->{make_code}{begin} =~ s/^\n//;
 	chomp($self->{make_code}{begin}) while $self->{make_code}{begin} =~ /\n$/s;
     }
-    $self->{Data}{begin} = $insert_comments || $insert_statements
-      ? ($insert_comments  =~ /\w/ ? "$insert_comments\n" : '') . "$note\n" . 
-        ($insert_statements =~ /\w/ ? "\n$insert_statements\n\n" : "\n") .
+    $self->{Data}{begin} = $comments_header || $code_header
+      ? ($comments_header  =~ /\w/ ? "$comments_header\n" : '') . "$note\n" . 
+        ($code_header =~ /\w/ ? "\n$code_header\n\n" : "\n") .
         $self->{Data}{begin}
       : "$note\n\n" . $self->{Data}{begin};
 }
 
 sub _write_begin {
     my $self = shift;  
-    my $INDENT = substr($self->{INDENT}, 0, length($self->{INDENT}) - 1);
+    my $INDENT = substr($self->{INDENT}, 0, length($self->{INDENT})-1);
     $self->_subst_makecode('begin');
     $self->{Data}{begin} =~ s/(\$INDENT)/$1/eego;
     $self->_do_verbose(File::Basename::basename($self->{Config}{Build_PL}), " written:\n", 2);
@@ -473,7 +529,7 @@ sub _write_args {
     my $self = shift;
     my $arg;
     my $regex = '$chunk =~ /=> \{/';
-    for my $chunk (@{$self->{buildargs_dumped}}) {
+    foreach my $chunk (@{$self->{buildargs_dumped}}) {
         # Hash/Array output                       
         if ($chunk =~ /=> [\{\[]/) {
 	    # Remove redundant parentheses
@@ -487,7 +543,7 @@ sub _write_args {
 	    my ($whitespace) = $lines[0] =~ /^(\s+)(\w+)/;
 	    $arg = $2;
 	    my $shorten = length($whitespace);
-            for (my $i = 0; $i < @lines; $i++) {
+            foreach (my $i = 0; $i < @lines; $i++) {
 	        my $line = $lines[$i];
 	        chomp($line);
 		# Remove additional whitespace
@@ -516,8 +572,8 @@ sub _write_args {
 	}
 	no warnings 'uninitialized';
 	if ($self->{make_code}{$arg}) {
-	    for my $line (@{$self->{make_code}{$arg}}) {
-	        $line .= ',' unless $line =~ /^#/;
+	    foreach my $line (@{$self->{make_code}{$arg}}) {
+	        $line .= ',' unless $line =~ /^\#/;
     	        $self->_do_verbose("$self->{INDENT}$line\n", 2);
 	        print "$self->{INDENT}$line\n";
 	    }
@@ -527,7 +583,7 @@ sub _write_args {
 
 sub _write_end {
     my $self = shift;
-    my $INDENT = substr($self->{INDENT}, 0, length($self->{INDENT}) - 1);
+    my $INDENT = substr($self->{INDENT}, 0, length($self->{INDENT})-1);
     $self->_subst_makecode('end');
     $self->{Data}{end} =~ s/(\$INDENT)/$1/eego;
     $self->_do_verbose($self->{Data}{end}, 2);
@@ -555,7 +611,7 @@ sub _add_to_manifest {
 	  or die "Can't open $self->{Config}{MANIFEST}: $!\n";
         print $fh sort @manifest;
         $fh->close;
-	print "Added to $self->{Config}{MANIFEST}: $self->{Config}{Build_PL}\n";
+	$self->_do_verbose("Added to $self->{Config}{MANIFEST}: $self->{Config}{Build_PL}\n");
     }
 }
 
@@ -570,7 +626,7 @@ sub _do_verbose {
 
 sub _debug {
     my $self = shift;
-    warn @_ if $self->{Config}{Debug};
+    warn @_ and <STDIN> if $self->{Config}{Debug};
 }
 
 1;
@@ -579,11 +635,11 @@ __DATA__
 # argument conversion 
 -
 NAME                  module_name
-#DISTNAME             dist_name
-#ABSTRACT             dist_abstract
-#AUTHOR               dist_author
-#VERSION              dist_version
-#VERSION_FROM         dist_version_from
+DISTNAME              dist_name
+ABSTRACT              dist_abstract
+AUTHOR                dist_author
+VERSION               dist_version
+VERSION_FROM          dist_version_from
 PREREQ_PM             requires
 PL_FILES              PL_files
 PM                    pm_files
@@ -597,7 +653,7 @@ EXTRA_META            meta_add
 SIGN                  sign
 LICENSE               license
 clean.FILES           @add_to_cleanup
- 
+
 # default arguments 
 -
 #build_requires       HASH
@@ -605,8 +661,8 @@ clean.FILES           @add_to_cleanup
 #conflicts	      HASH
 license               unknown
 create_readme         1
-create_makefile_pl    passthrough
- 
+create_makefile_pl    traditional
+
 # sorting order 
 -
 module_name
@@ -658,7 +714,7 @@ Module::Build::Convert - Makefile.PL to Build.PL converter
 
 =head1 SYNOPSIS
 
- require Module::Build::Convert; 
+ use Module::Build::Convert; 
 
  my %params = (Path => '/path/to/perl/distribution',
                Verbose => 2,
@@ -682,13 +738,13 @@ intended to ease the transition process.
 
 =head2 new
 
-Possible arguments:
+Options:
 
 =over 4
 
 =item Path
 
-Path to a Perl distribution. Default: undef
+Path to a Perl distribution. Default: C<''>
 
 =item Makefile_PL
 
@@ -713,7 +769,7 @@ Default: 0
 
 =item Exec_Makefile
 
-Execute the Makefile.PL via do 'Makefile.PL'.
+Execute the Makefile.PL via C<'do Makefile.PL'>.
 Default: 0
 
 =item Verbose
@@ -754,7 +810,7 @@ C<Data::Dumper> sort keys. Default: 1
 
 =head2 convert
 
-Parses the F<Makefile.PL>'s C<ExtUtils::MakeMaker> arguments and converts them
+Parses the F<Makefile.PL>'s C<WriteMakefile()> arguments and converts them
 to C<Module::Build> equivalents; subsequently the according F<Build.PL>
 is created. Takes no arguments.
 
@@ -791,12 +847,12 @@ that is, C<HASH> -> C<HASH>, etc.
 C<Module::Build> default arguments may be specified as key/value pairs. 
 Arguments attached to multidimensional structures are unsupported.
 
- build_requires        HASH
- recommends	       HASH
- conflicts	       HASH
+ #build_requires       HASH
+ #recommends	       HASH
+ #conflicts	       HASH
  license               unknown
  create_readme         1
- create_makefile_pl    passthrough
+ create_makefile_pl    traditional
 
 Value may be either a string or of type C<SCALAR, ARRAY, HASH>.
 
@@ -835,6 +891,9 @@ unsorted order after preceedingly sorted arguments.
 
 Code that preceeds converted C<Module::Build> arguments.
 
+ use strict;
+ use warnings;
+
  use Module::Build;
 
  $MAKECODE
@@ -869,6 +928,16 @@ arguments are then accessible to the internal sub.
 Converted C<ExtUtils::MakeMaker> arguments will be dumped by 
 C<Data::Dumper's> C<Dump()> and are then furtherly processed.
 
+=head1 BUGS & CAVEATS
+
+C<Module::Build::Convert> should be considered experimental as the parsing 
+of the Makefile.PL doesn't necessarily return valid arguments, especially for
+Makefiles with bad or even worse, missing intendation.
+
+The parsing process may sometimes hang with or without warnings in such cases.
+Debugging by using the appropriate option/switch (see CONSTRUCTOR/new) may reveal
+the root cause.
+
 =head1 SEE ALSO
 
 L<http://www.makemaker.org>, L<ExtUtils::MakeMaker>, L<Module::Build>, 
@@ -876,7 +945,7 @@ L<http://www.makemaker.org/wiki/index.cgi?ModuleBuildConversionGuide>
 
 =head1 AUTHOR
 
-Steven Schubiger, schubiger@cpan.org
+Steven Schubiger <schubiger@cpan.org>
 
 =head1 LICENSE
 
